smartcard.Synchronization.Synchronization

# ``smartcard`.`Synchronization`.`Synchronization``

class documentation

`class Synchronization(object):`

Known subclasses: `smartcard.CardNames.__CardNames__`, `smartcard.Observer.Observable`

View In Hierarchy

Undocumented

Method | `__init__` | Undocumented
Instance Variable | `mutex` | Undocumented

def __init__(self):
overridden in `smartcard.CardNames.__CardNames__`, `smartcard.Observer.Observable`

Undocumented

mutex =

Undocumented